==> oscars_mgmnt-0.1.65-py3-none-any.whl: oscars_mgmnt/ingestion.py <==
"""
Created on 02 July 2019

@author: Tonneau Stephane
@author: Dirk Daems
"""
import glob
from typing import Optional
import oscars_mgmnt.utils.storage
from oscars_mgmnt.file_object import ObjectInfo


class MetadataIngester(object):
    """Class that is responsible for the ingestion of EO product metadata"""

    def __init__(self, prod_path, product_filter, metaparser=None, es_source_host=None, es_source_index=None):
        """
        Constructor of the class.
        """
        self.prod_path = prod_path
        self.prod_filter = product_filter

        if isinstance(metaparser, str):
            # create metaparser object from class reference
            import importlib
            from oscars_mgmnt.parser.es_parser import ElasticsearchParser
            module_name, class_name = metaparser.rsplit('.', 1)
            module = importlib.import_module(module_name)
            parser_class = getattr(module, class_name)

            if issubclass(parser_class, ElasticsearchParser):
                self.metaparser = parser_class(es_source_host=es_source_host, es_source_index=es_source_index)
            else:
                self.metaparser = parser_class()
        else:
            self.metaparser = metaparser

        if self.metaparser is None:
            if any(path_substr in self.prod_path for path_substr in ["CGS_S2", "TERRASCOPE_Sentinel2"]):
                if es_source_host is not None and es_source_index is not None:
                    from oscars_mgmnt.parser.es_parser import Sentinel2_ES_Parser
                    self.metaparser = Sentinel2_ES_Parser(es_source_host=es_source_host, es_source_index=es_source_index)
                else:
                    from oscars_mgmnt.parser.inspire import CGS_S2_Parser
                    self.metaparser = CGS_S2_Parser()
            elif any(path_substr in self.prod_path for path_substr in ["CGS_S1", "TERRASCOPE_Sentinel1"]):
                if es_source_host is not None and es_source_index is not None:
                    from oscars_mgmnt.parser.es_parser import Sentinel1_ES_Parser
                    self.metaparser = Sentinel1_ES_Parser(es_source_host=es_source_host, es_source_index=es_source_index)
                else:
                    from oscars_mgmnt.parser.inspire import CGS_S1_Parser
                    self.metaparser = CGS_S1_Parser()
            elif any(path_substr in self.prod_path for path_substr in ["CGS_S5P", "TERRASCOPE_Sentinel5P",'S5P','s5p']):
                from oscars_mgmnt.parser.es_parser import Sentinel5P_ES_Parser
                self.metaparser = Sentinel5P_ES_Parser(es_source_host=es_source_host, es_source_index=es_source_index)
            elif all(substr.lower() in self.prod_path.lower() for substr in ["PROBAV", "V2"]):
                from oscars_mgmnt.parser.hma import ProbavV2Parser
                self.metaparser = ProbavV2Parser()
            elif "PROBAV_L3" in self.prod_path:
                from oscars_mgmnt.parser.hma import ProbavSynthesisParser
                self.metaparser = ProbavSynthesisParser()
            elif "PROBAV_L2A" in self.prod_path:
                from oscars_mgmnt.parser.hma import ProbavL2Parser
                self.metaparser = ProbavL2Parser()
            elif any(substr in self.prod_path for substr in ["HRVPP", "hr-vpp"]) and es_source_host is not None and es_source_index is not None:
                from oscars_mgmnt.parser.es_parser import CLMS_HRVPP_ES_Parser
                self.metaparser = CLMS_HRVPP_ES_Parser(es_source_host=es_source_host, es_source_index=es_source_index)
            elif "COPERNICUS-DEM" in self.prod_path:
                from oscars_mgmnt.parser.inspire import DEMParser
                self.metaparser = DEMParser()
            elif "WORLDCOVER" in self.prod_path:
                from oscars_mgmnt.parser.filename import WorldCoverParser
                self.metaparser = WorldCoverParser()
            elif "VGT" in self.prod_path.upper():
                from oscars_mgmnt.parser.hma import SpotVgtParser
                if "FreeP" in self.prod_path:
                    self.metaparser = SpotVgtParser("SpotVGT_P.template")
                else:
                    self.metaparser = SpotVgtParser()
        self.res_writers = []
        self.storage: Optional[oscars_mgmnt.utils.storage.StorageInput] = None

    def with_template(self, template):
        """Method that fixes the jinja2 template to use in the process
        of translation of xml files to geojson files.

        :param template:the path to a jinja2 template.
        :type template: a string
        :returns: the object itself
        :rtype: a MetadataIngester
        """
        if self.metaparser is None:
            return None
        if template is not None:
            self.metaparser.with_template(template)
        return self

    def with_writer(self, writer):
        """Method that appends a new storage writing component to the list
        of referenced storage location.

        :param writer: a storage location writer such as FileWriter, KafkaWriter, ...
        :type writer: an OutputWriter
        :returns: the object itself
        :rtype: a MetadataIngester
        """
        self.res_writers.append(writer)
        return self

    def ingest_metadata(self):
        """Method that launches the process of
        - product path analysis
        - xml metadata translation to geojson equivalence
        - storing of the geojson files in the configured storage locations.
        """
        # Checking the parser
        if self.metaparser is None:
            raise Exception('No template available for parsing')

        # Reading the file system
        path_cnt = 0
        product_cnt = 0
        for filename in self.storage.glob(self.prod_path):
            path_cnt += 1
            product_file_infos = ObjectInfo.from_regexp(self.storage, filename, self.prod_filter)
            for file_infos in product_file_infos.items():
                filled_templates = self.metaparser.convert(file_infos[1])
                for uid in filled_templates:
                    product_cnt += 1
                    for writer in self.res_writers:
                        writer.output(uid, filled_templates[uid])
        if path_cnt < 1 or product_cnt < 1:
            from oscars_mgmnt.utils.common import last_iglob
            from fire.core import FireExit
            last_iglob("No entries found.  Best matching product entry is", self.prod_path)
            # exit with status code 3 (exit code 2 is default error code for Fire)
            raise FireExit(3, None)

    def flush(self):
        """Method that flushes the storage queue of all referenced storage systems.
        """
        for writer in self.res_writers:
            writer.flush()

==> oscars_mgmnt-0.1.69-py3-none-any.whl: oscars_mgmnt/ingestion.py <==
"""
Created on 02 July 2019

@author: Tonneau Stephane
@author: Dirk Daems
"""
import glob
from typing import Optional
import oscars_mgmnt.utils.storage
from oscars_mgmnt.file_object import ObjectInfo


class MetadataIngester(object):
    """Class that is responsible for the ingestion of EO product metadata"""

    def __init__(self, prod_path, product_filter, metaparser=None, es_source_host=None, es_source_index=None):
        """
        Constructor of the class.
        """
        self.prod_path = prod_path
        self.prod_filter = product_filter

        if isinstance(metaparser, str):
            # create metaparser object from class reference
            import importlib
            from oscars_mgmnt.parser.es_parser import ElasticsearchParser
            module_name, class_name = metaparser.rsplit('.', 1)
            module = importlib.import_module(module_name)
            parser_class = getattr(module, class_name)

            if issubclass(parser_class, ElasticsearchParser):
                self.metaparser = parser_class(es_source_host=es_source_host, es_source_index=es_source_index)
            else:
                self.metaparser = parser_class()
        else:
            self.metaparser = metaparser

        if self.metaparser is None:
            if any(path_substr in self.prod_path for path_substr in ["CGS_S2", "TERRASCOPE_Sentinel2"]):
                if es_source_host is not None and es_source_index is not None:
                    from oscars_mgmnt.parser.es_parser import Sentinel2_ES_Parser
                    self.metaparser = Sentinel2_ES_Parser(es_source_host=es_source_host, es_source_index=es_source_index)
                else:
                    from oscars_mgmnt.parser.inspire import CGS_S2_Parser
                    self.metaparser = CGS_S2_Parser()
            elif any(path_substr in self.prod_path for path_substr in ["CGS_S1", "TERRASCOPE_Sentinel1"]):
                if es_source_host is not None and es_source_index is not None:
                    from oscars_mgmnt.parser.es_parser import Sentinel1_ES_Parser
                    self.metaparser = Sentinel1_ES_Parser(es_source_host=es_source_host, es_source_index=es_source_index)
                else:
                    from oscars_mgmnt.parser.inspire import CGS_S1_Parser
                    self.metaparser = CGS_S1_Parser()
            elif any(path_substr in self.prod_path for path_substr in ["CGS_S5P", "TERRASCOPE_Sentinel5P",'S5P','s5p']):
                from oscars_mgmnt.parser.es_parser import Sentinel5P_ES_Parser
                self.metaparser = Sentinel5P_ES_Parser(es_source_host=es_source_host, es_source_index=es_source_index)
            elif all(substr.lower() in self.prod_path.lower() for substr in ["PROBAV", "V2"]):
                from oscars_mgmnt.parser.hma import ProbavV2Parser
                self.metaparser = ProbavV2Parser()
            elif "PROBAV_L3" in self.prod_path:
                from oscars_mgmnt.parser.hma import ProbavSynthesisParser
                self.metaparser = ProbavSynthesisParser()
            elif "PROBAV_L2A" in self.prod_path:
                from oscars_mgmnt.parser.hma import ProbavL2Parser
                self.metaparser = ProbavL2Parser()
            elif any(substr in self.prod_path for substr in ["HRVPP", "hr-vpp"]) and es_source_host is not None and es_source_index is not None:
                from oscars_mgmnt.parser.es_parser import CLMS_HRVPP_ES_Parser
                self.metaparser = CLMS_HRVPP_ES_Parser(es_source_host=es_source_host, es_source_index=es_source_index)
            elif "COPERNICUS-DEM" in self.prod_path:
                from oscars_mgmnt.parser.inspire import DEMParser
                self.metaparser = DEMParser()
            elif "WORLDCOVER".lower() in self.prod_path.lower():
                from oscars_mgmnt.parser.filename import WorldCoverParser
                self.metaparser = WorldCoverParser()
            elif "VGT" in self.prod_path.upper():
                from oscars_mgmnt.parser.hma import SpotVgtParser
                if "FreeP" in self.prod_path:
                    self.metaparser = SpotVgtParser("SpotVGT_P.template")
                else:
                    self.metaparser = SpotVgtParser()
        self.res_writers = []
        self.storage: Optional[oscars_mgmnt.utils.storage.StorageInput] = None

    def with_template(self, template):
        """Method that fixes the jinja2 template to use in the process
        of translation of xml files to geojson files.

        :param template:the path to a jinja2 template.
        :type template: a string
        :returns: the object itself
        :rtype: a MetadataIngester
        """
        if self.metaparser is None:
            return None
        if template is not None:
            self.metaparser.with_template(template)
        return self

    def with_writer(self, writer):
        """Method that appends a new storage writing component to the list
        of referenced storage location.

        :param writer: a storage location writer such as FileWriter, KafkaWriter, ...
        :type writer: an OutputWriter
        :returns: the object itself
        :rtype: a MetadataIngester
        """
        self.res_writers.append(writer)
        return self

    def ingest_metadata(self):
        """Method that launches the process of
        - product path analysis
        - xml metadata translation to geojson equivalence
        - storing of the geojson files in the configured storage locations.
        """
        # Checking the parser
        if self.metaparser is None:
            raise Exception('No template available for parsing')

        # Reading the file system
        path_cnt = 0
        product_cnt = 0
        for filename in self.storage.glob(self.prod_path):
            path_cnt += 1
            product_file_infos = ObjectInfo.from_regexp(self.storage, filename, self.prod_filter)
            for file_infos in product_file_infos.items():
                filled_templates = self.metaparser.convert(file_infos[1])
                for uid in filled_templates:
                    product_cnt += 1
                    for writer in self.res_writers:
                        writer.output(uid, filled_templates[uid])
        if path_cnt < 1 or product_cnt < 1:
            from oscars_mgmnt.utils.common import last_iglob
            from fire.core import FireExit
            last_iglob("No entries found.  Best matching product entry is", self.prod_path)
            # exit with status code 3 (exit code 2 is default error code for Fire)
            raise FireExit(3, None)

    def flush(self):
        """Method that flushes the storage queue of all referenced storage systems.
        """
        for writer in self.res_writers:
            writer.flush()
